function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useRef, useState, useImperativeHandle } from 'react';
import classNames from 'classnames';
import KeyCode from "rc-util/es/KeyCode";
import List from 'rc-virtual-list';
import Option from './Option';

var OptionList = function OptionList(_ref, ref) {
  var prefixCls = _ref.prefixCls,
      data = _ref.data,
      _ref$itemKey = _ref.itemKey,
      itemKey = _ref$itemKey === void 0 ? "key" : _ref$itemKey,
      height = _ref.height,
      itemHeight = _ref.itemHeight,
      onSelect = _ref.onSelect,
      onToggle = _ref.onToggle,
      onScroll = _ref.onScroll,
      notFoundContent = _ref.notFoundContent;
  var listRef = useRef(null);

  var scrollIntoView = function scrollIntoView(index) {
    if (listRef.current) {
      listRef.current.scrollTo({
        index: index
      });
    }
  };

  var getActiveIndex = function getActiveIndex(index) {
    var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    var len = data.length;

    for (var i = 0; i < len; i++) {
      var current = (index + i * offset + len) % len;
      return current;
    }

    return -1;
  };

  var _useState = useState(function () {
    return getActiveIndex(0);
  }),
      _useState2 = _slicedToArray(_useState, 2),
      activeIndex = _useState2[0],
      setActiveIndex = _useState2[1];

  var onListMouseDown = function onListMouseDown(e) {
    e.preventDefault();
  }; // ================= Keyboard =================


  useImperativeHandle(ref, function () {
    return {
      onKeyDown: function onKeyDown(e) {
        var which = e.which;

        switch (which) {
          case KeyCode.UP:
          case KeyCode.DOWN:
            {
              var offset = 0;

              if (which === KeyCode.UP) {
                offset = -1;
              } else if (which === KeyCode.DOWN) {
                offset = 1;
              }

              if (offset !== 0) {
                var nextActiveIndex = getActiveIndex(activeIndex + offset, offset);
                scrollIntoView(nextActiveIndex);
                setActiveIndex(nextActiveIndex);
              }

              break;
            }

          case KeyCode.ENTER:
            {
              var selectItem = data[activeIndex];
              onSelect(selectItem);
              break;
            }

          case KeyCode.ESC:
            {
              if (onToggle) {
                onToggle(false);
              }
            }
        }
      }
    };
  }); // ================= render =================

  if (data.length === 0) {
    return React.createElement("div", {
      className: "".concat(prefixCls, "-empty"),
      onMouseDown: onListMouseDown
    }, notFoundContent);
  }

  return React.createElement(List, {
    component: "ul",
    className: "".concat(prefixCls, "-list"),
    itemKey: itemKey,
    ref: listRef,
    data: data,
    height: height,
    itemHeight: itemHeight,
    fullHeight: false,
    onScroll: onScroll,
    onMouseDown: onListMouseDown
  }, function (item, itemIndex) {
    var optionPrefixCls = "".concat(prefixCls, "-list-option");
    var optionClassName = classNames(_defineProperty({}, "".concat(optionPrefixCls, "__active"), activeIndex === itemIndex));
    return React.createElement(Option, {
      prefixCls: prefixCls,
      className: optionClassName,
      item: item,
      onClick: onSelect
    });
  });
};

var RefOptionList = React.forwardRef(OptionList);
RefOptionList.displayName = "OptionList";
export default RefOptionList;