import React, { Component, UIEventHandler } from 'react';
import { RefOptionListProps } from './OptionList';
import { Omit } from '../_util/type';
import { InputProps } from 'antd/lib/input';
import './style';
export interface Result {
    errorCode?: number;
    data?: any;
    msg?: string;
}
export interface PanelData {
    title: string;
    code: string;
    maxLevel: number;
    items: Array<TabData>;
}
export interface TabData {
    title: string;
    level: number;
    entry: boolean;
    items: Array<Item>;
}
export interface Pagination {
    currentPage: number;
    currentResult: number;
    pageSize: number;
    totalPage: number;
    totalResult: number;
}
export interface TabInputProps extends Omit<InputProps, 'onBlur' | 'onClick' | 'onChange'> {
    renderValue?: (selectedItems: Array<Item>) => string;
}
export interface CascaderProps {
    value?: Array<Item>;
    dataSource: Array<PanelData>;
    prefixCls?: string;
    className?: string;
    hint?: string | React.ReactNode;
    style?: React.CSSProperties;
    contentStyle?: React.CSSProperties;
    contentCls?: string;
    colSpan?: number;
    inputProps?: TabInputProps;
    pagination?: Boolean | Pagination;
    listHeight?: number;
    listItemHeight?: number;
    onItemClick?: (key: number, topKey: number, item: Item) => Promise<any>;
    onSearchItemClick?: (item: Item) => Promise<any>;
    onTopTabChange?: (topKey: number) => void;
    onTabChange?: (key: number, topKey: number, item: Item | undefined) => Promise<Result>;
    onSearch?: (params: any) => Promise<any>;
    onBlur?: React.FocusEventHandler<Element>;
    onChange?: Function;
    onClear?: Function;
    onPopupScroll?: UIEventHandler<HTMLDivElement>;
}
export interface Item {
    code: string;
    name: string;
    level: number;
    groupCode: string;
    parentCode?: string;
    parents: Array<Item>;
    [key: string]: any;
}
export interface CascaderState {
    firstTab: number;
    secondTab: number;
    inputVal: string;
    selectedItems: Array<Item>;
    visible: Boolean;
    searchVisible: Boolean;
    tabLoading: Boolean;
    isSearching: Boolean;
    fetchList: Array<any>;
    pagination?: Pagination;
}
export default class TabCascader extends Component<CascaderProps, CascaderState> {
    el: HTMLDivElement | null;
    debounceSearch: Function;
    listRef: React.RefObject<RefOptionListProps>;
    static defaultProps: {
        prefixCls: string;
        colSpan: number;
    };
    constructor(props: CascaderProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentWillReceiveProps(nextProps: CascaderProps): void;
    renderValue: (items: Item[]) => string;
    initPagination: () => void;
    setInitialValue: (dataSource: PanelData[], value: Item[]) => void;
    handleOutsideClick: (e: MouseEvent) => void;
    handleTopTabChange: (tabKey: string) => void;
    handleSecondTabChange: (tabKey: string) => void;
    handleClickItem: (item: Item) => void;
    handleSearchItemClick: (item: Item) => Promise<void>;
    hanldeInputChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
    handleSearch: (val: string) => void;
    handleInputClick: (e: React.MouseEvent<HTMLInputElement, MouseEvent>) => void;
    handleInputBlur: (e: React.FocusEvent<HTMLInputElement>) => void;
    handleSearchScroll: (e: React.UIEvent<HTMLDivElement>) => void;
    onToggleDropdown: (flag?: boolean) => void;
    handleKeyDown: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    renderItems: (tabItem: TabData) => JSX.Element;
    renderContent: () => JSX.Element;
    renderSearchSection(): JSX.Element;
    render(): JSX.Element;
}
